@@ -102,7 +102,7 @@ struct _VteTerminalClass {
 	void (*copy_clipboard)(VteTerminal* terminal);
 	void (*paste_clipboard)(VteTerminal* terminal);
 
- 	void (*beep)(VteTerminal* terminal);
+	void (*bell)(VteTerminal* terminal);
 
         /* Padding for future expansion. */
         gpointer padding[16];
@@ -183,9 +183,6 @@ gdouble vte_terminal_get_font_scale(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 void vte_terminal_set_audible_bell(VteTerminal *terminal,
                                    gboolean is_audible) _VTE_GNUC_NONNULL(1);
 gboolean vte_terminal_get_audible_bell(VteTerminal *terminal);
-void vte_terminal_set_visible_bell(VteTerminal *terminal,
-                                   gboolean is_visible) _VTE_GNUC_NONNULL(1);
-gboolean vte_terminal_get_visible_bell(VteTerminal *terminal);
 void vte_terminal_set_scroll_on_output(VteTerminal *terminal,
                                        gboolean scroll) _VTE_GNUC_NONNULL(1);
 void vte_terminal_set_scroll_on_keystroke(VteTerminal *terminal,
@@ -197,8 +194,6 @@ gboolean vte_terminal_get_rewrap_on_resize(VteTerminal *terminal) _VTE_GNUC_NONN
 /* Set the color scheme. */
 void vte_terminal_set_color_bold(VteTerminal *terminal,
                                  const GdkRGBA *bold) _VTE_GNUC_NONNULL(1);
-void vte_terminal_set_color_dim(VteTerminal *terminal,
-                                const GdkRGBA *dim) _VTE_GNUC_NONNULL(1);
 void vte_terminal_set_color_foreground(VteTerminal *terminal,
                                        const GdkRGBA *foreground) _VTE_GNUC_NONNULL(1) _VTE_GNUC_NONNULL(2);
 void vte_terminal_set_color_background(VteTerminal *terminal,
